@media (min-width: 992px) {
  .rounded-lg-3 {
    border-radius: .3rem;
  }
}

.alert {
  width: 40%;
  font-size: .5rem;
}

.collapse {
  &:not(.show) {
    display: none;
  }
}

.collapsing {
  height: 0;
  overflow: hidden;
  @include transition($transition-collapse);

  &.collapse-horizontal {
    width: 0;
    height: auto;
    @include transition($transition-collapse-width);
  }
}